TextLen

Trait TextLen 

pub trait TextLen: Copy + Sealed {
    // Required method
    fn text_len(self) -> TextSize;
}
Byte offset range in the source text. Re-exported from text-size for convenience so downstream crates can depend only on cyrs-syntax. Primitives with a textual length that can be passed to TextSize::of.

Required Methods

fn text_len(self) -> TextSize

The textual length of this primitive.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl TextLen for &str

Source

impl TextLen for &String

Source

impl TextLen for char

Implementors