pub trait TextLen: Copy + Sealed {
// Required method
fn text_len(self) -> TextSize;
}Expand description
Byte offset range in the source text. Re-exported from text-size for
convenience so downstream crates can depend only on cyrs-syntax.
Primitives with a textual length that can be passed to TextSize::of.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.